module("beehive.search.CategoryAndFilters")
.require("ui.Core", 
         "ui.Group",
         "ui.Button",
         "beehive.search.CategoryDropdown")
.declare("beehive.search.CategoryAndFilters").extend("ui.Group")
.as({
    widgetName:"CategoryAndFilters",

    events:["ready","change"],

    options:{
        view:"%modulePaths.beehiveViews%/CategoryAndFiltersView.html",
        viewType:"file",
        layoutOptions:{
            layout:"horizontal",
            hlayout:"1 0",
            hFillStrategy:"first",
            childSelector:"> .child"
        },
        isACDFamilyProduct: false,
        lang: {
            noFilters: "{{str:SET_FILTER|Set Filter}}",
            hasFilters: "{{str:CURRENT_FILTER|Current Filter:}}",
            disabledFilters: "{{str:DISABLED_FILTERS|No Filter for {{audience}}}}"
        }
    },

    styles:["%modulePaths.beehiveStyles%/category-selector-theme.css"],

    content:{
        "categorySelector":{
            type:"beehive.search.CategoryDropdown",
            options:{
                defaultHeaderData:"{{str:CHOOSE_OPTION|Choose an option...}}"
            },
            categoriesReady:function(){
                this.trigger("ready");
            },
            itemSelected:function(e){
                if (this.options.isACDFamilyProduct) {
                    this._setAudience(e.itemData.value.audience);
                }
                this._onChange();
            }
        },
        "filters": {
            type:"button",
            options:{
                label:"",
                text:false,
                icons:{
                    primary:"beehive-filter-icon"
                }
            },
            click: function(e){
                if ($(e.currentTarget).hasClass("ui-state-disabled")) {
                    return;
                }

                e.stopPropagation();
                this._toggleMenu();
            }
        }
    },

    _init: function(){
        var self = this;

        this.base();

        if (this.options.isACDFamilyProduct) {
            this.element.addClass("acd-family-product");
            this._initFilterMenu();

            this.element.delegate(".web-results input", "click", function() {
                self._onChange();
            });
            
            this.cookieWorker = new CookieWorker(top.document, "autodesk_online_help_settings", 24000);
        }

        this.byId("categorySelector").option("productInfo", this.options.productInfo);
        
        this.bind("ready", function() {
            self.__isReady = true;
            
            // clean our cache
            delete self.options.__subType;
        });
    },

    updateDisplay: function() {
        this.base();
        
        // load settings from cookie after render
        if (this.cookieWorker) {
            var settings = {};
            this.cookieWorker.load(settings);

            if (settings) {
                this.byId("categorySelector").option("defaultIndex", settings.audienceIndex);
                // cache this for later as _setAudience would reset the checkboxes if set here
                this.options.__subType = (settings.subType || "").split(",");

                this.element.find(".web-results input")[0].checked = settings.source !== 'help';
            } else {
                this.element.find(".web-results input")[0].checked = true;
            }
        }
    },

    _onChange: function() {
        if (!this.__isReady) return;

        if (this.options.isACDFamilyProduct) {
            this._updateButtonTooltip();

            if (this.__isReady) {
                this.cookieWorker.store(({
                    audienceIndex: this.byId("categorySelector").selectedItemIndex(),
                    source: this.sourceData(),
                    subType: this.filterData()
                }));
            }
        }

        this.trigger("change");
    },

    _setAudience: function(audience){
        var config = module.getConfig("beehiveSearchPanel.filterRelationships"),
            filterToggler = this.byId("filters").element,
            filterMenu = this.element.find(".ui-filter-menu"),
            cachedSubType = this.options.__subType;

        if (!config[audience] || config[audience].length) {
            filterToggler.removeClass("ui-state-disabled");

            filterMenu.find('input').each(function(i, element) {
                if (cachedSubType) {
                    element.checked = $.inArray(element.getAttribute("value"), cachedSubType) !== -1;
                } else {
                    element.checked = false;
                }
                if (!config[audience] || $.inArray(element.getAttribute("value"), config[audience]) !== -1) {
                    $(element.parentNode).show();
                } else {
                    $(element.parentNode).hide();
                }
            });
        } else {
            filterToggler.addClass("ui-state-disabled");
            filterMenu.find('input').each(function(i, element) {
                element.checked = false;
            });
        }
        
        this._updateButtonTooltip();
    },

    _updateButtonTooltip: function() {
        var filterToggler = this.byId("filters").element,
            filters = [],
            filterNames = "",
            audience = this.byId("categorySelector").selectedItemData().title,
            self = this;

        if (filterToggler.hasClass("ui-state-disabled")) {
            filterToggler.attr("title", module.tokenReplace(this.options.lang.disabledFilters, {audience: audience}));
            filterToggler.removeClass("with-filters");
        } else {
            filters = this.filterData();

            if (!filters.length) {
                filterToggler.removeClass("with-filters");
                filterToggler.attr("title", module.tokenReplace(this.options.lang.noFilters));
            } else {
                filterToggler.addClass("with-filters");

                filterNames = $.map(filters, function(filter){ 
                    return self.element.find('input[value="' + filter + '"]').nextAll('span').text();
                }).join(", ");

                filterToggler.attr("title", module.tokenReplace(this.options.lang.hasFilters) + " " + filterNames);
            }
        }
    },

    _toggleMenu: function() {
        if (this.element.find(".ui-filter-menu").hasClass("visible")) {
            this._hideMenu();
        } else {
            this._showMenu();
        }
    },

    _showMenu: function() {
        this.element.find(".ui-filter-menu").addClass("visible");
    },

    _hideMenu: function() {
        this.element.find(".ui-filter-menu").removeClass("visible");
    },

    _initFilterMenu: function(){
        var self = this;

        this.element.delegate(".ui-filter-menu input", "click", function(e){
                e.stopPropagation();

                self._onChange();
            })
            .delegate(".ui-filter-menu li.filter", "click", function(e){
                if (e.target.tagName.toLowerCase() === 'input') return;

                var input = $(this).find("input");

                input[0].checked = !input[0].checked;

                self._onChange();
            }).delegate(".ui-filter-menu", "click", function(e){
                    e.stopPropagation();
            });

        $(document.body).bind({
            click: $.proxy(this._hideMenu, this),
            mouseleave: function() {
                if (self.__filterMenuTimeout) clearTimeout(self.__filterMenuTimeout);
                self.__filterMenuTimeout = setTimeout($.proxy(self._hideMenu, self), 1200);
            },
            mouseenter: function() {
                if (self.__filterMenuTimeout) {
                    clearTimeout(self.__filterMenuTimeout);
                    self.__filterMenuTimeout = null;
                }
            }
        });
    },

    categoryData: function(){
        return this.byId("categorySelector").selectedItemData();
    },

    filterData: function() {
        if (this.options.isACDFamilyProduct) {
            var checked = this.element.find(".ui-filter-menu input:checked");

            return $.map(checked, function(element){ return element.getAttribute("value")});
        } else {
            return [];
        }
    },

    sourceData: function() {
        if (this.options.isACDFamilyProduct && !this.element.find(".web-results input").is(":checked")) {
            return "help";
        } else {
            return this.categoryData().value.source;
        }
    }
});
// SIG // Begin signature block
// SIG // MIIZNgYJKoZIhvcNAQcCoIIZJzCCGSMCAQExCzAJBgUr
// SIG // DgMCGgUAMGcGCisGAQQBgjcCAQSgWTBXMDIGCisGAQQB
// SIG // gjcCAR4wJAIBAQQQEODJBs441BGiowAQS9NQkAIBAAIB
// SIG // AAIBAAIBAAIBADAhMAkGBSsOAwIaBQAEFEXYcS59qf/a
// SIG // vJwP23MG3AHEVNlkoIIUMDCCA+4wggNXoAMCAQICEH6T
// SIG // 6/t8xk5Z6kuad9QG/DswDQYJKoZIhvcNAQEFBQAwgYsx
// SIG // CzAJBgNVBAYTAlpBMRUwEwYDVQQIEwxXZXN0ZXJuIENh
// SIG // cGUxFDASBgNVBAcTC0R1cmJhbnZpbGxlMQ8wDQYDVQQK
// SIG // EwZUaGF3dGUxHTAbBgNVBAsTFFRoYXd0ZSBDZXJ0aWZp
// SIG // Y2F0aW9uMR8wHQYDVQQDExZUaGF3dGUgVGltZXN0YW1w
// SIG // aW5nIENBMB4XDTEyMTIyMTAwMDAwMFoXDTIwMTIzMDIz
// SIG // NTk1OVowXjELMAkGA1UEBhMCVVMxHTAbBgNVBAoTFFN5
// SIG // bWFudGVjIENvcnBvcmF0aW9uMTAwLgYDVQQDEydTeW1h
// SIG // bnRlYyBUaW1lIFN0YW1waW5nIFNlcnZpY2VzIENBIC0g
// SIG // RzIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB
// SIG // AQCxrLNJVEuXHBIK2CV5kSJXKm/cuCbEQ3Nrwr8uUFr7
// SIG // FMJ2jkMBJUO0oeJF9Oi3e8N0zCLXtJQAAvdN7b+0t0Qk
// SIG // a81fRTvRRM5DEnMXgotptCvLmR6schsmTXEfsTHd+1Fh
// SIG // AlOmqvVJLAV4RaUvic7nmef+jOJXPz3GktxK+Hsz5HkK
// SIG // +/B1iEGc/8UDUZmq12yfk2mHZSmDhcJgFMTIyTsU2sCB
// SIG // 8B8NdN6SIqvK9/t0fCfm90obf6fDni2uiuqm5qonFn1h
// SIG // 95hxEbziUKFL5V365Q6nLJ+qZSDT2JboyHylTkhE/xni
// SIG // RAeSC9dohIBdanhkRc1gRn5UwRN8xXnxycFxAgMBAAGj
// SIG // gfowgfcwHQYDVR0OBBYEFF+a9W5czMx0mtTdfe8/2+xM
// SIG // gC7dMDIGCCsGAQUFBwEBBCYwJDAiBggrBgEFBQcwAYYW
// SIG // aHR0cDovL29jc3AudGhhd3RlLmNvbTASBgNVHRMBAf8E
// SIG // CDAGAQH/AgEAMD8GA1UdHwQ4MDYwNKAyoDCGLmh0dHA6
// SIG // Ly9jcmwudGhhd3RlLmNvbS9UaGF3dGVUaW1lc3RhbXBp
// SIG // bmdDQS5jcmwwEwYDVR0lBAwwCgYIKwYBBQUHAwgwDgYD
// SIG // VR0PAQH/BAQDAgEGMCgGA1UdEQQhMB+kHTAbMRkwFwYD
// SIG // VQQDExBUaW1lU3RhbXAtMjA0OC0xMA0GCSqGSIb3DQEB
// SIG // BQUAA4GBAAMJm495739ZMKrvaLX64wkdu0+CBl03X6ZS
// SIG // nxaN6hySCURu9W3rWHww6PlpjSNzCxJvR6muORH4KrGb
// SIG // sBrDjutZlgCtzgxNstAxpghcKnr84nodV0yoZRjpeUBi
// SIG // JZZux8c3aoMhCI5B6t3ZVz8dd0mHKhYGXqY4aiISo1EZ
// SIG // g362MIIEozCCA4ugAwIBAgIQDs/0OMj+vzVuBNhqmBsa
// SIG // UDANBgkqhkiG9w0BAQUFADBeMQswCQYDVQQGEwJVUzEd
// SIG // MBsGA1UEChMUU3ltYW50ZWMgQ29ycG9yYXRpb24xMDAu
// SIG // BgNVBAMTJ1N5bWFudGVjIFRpbWUgU3RhbXBpbmcgU2Vy
// SIG // dmljZXMgQ0EgLSBHMjAeFw0xMjEwMTgwMDAwMDBaFw0y
// SIG // MDEyMjkyMzU5NTlaMGIxCzAJBgNVBAYTAlVTMR0wGwYD
// SIG // VQQKExRTeW1hbnRlYyBDb3Jwb3JhdGlvbjE0MDIGA1UE
// SIG // AxMrU3ltYW50ZWMgVGltZSBTdGFtcGluZyBTZXJ2aWNl
// SIG // cyBTaWduZXIgLSBHNDCCASIwDQYJKoZIhvcNAQEBBQAD
// SIG // ggEPADCCAQoCggEBAKJjCzlEuLsjp0RJuw7/ofBhClOT
// SIG // sJjbrSwPSsVu/4Y8U1UPFc4EPyv9qZaW2b5heQtbyUyG
// SIG // duXgQ0sile7CK0PBn9hotI5AT+6FOLkRxSPyZFjwFTJv
// SIG // TlehroikAtcqHs1L4d1j1ReJMluwXplaqJ0oUA4X7pbb
// SIG // YTtFUR3PElYLkkf8q672Zj1HrHBy55LnX80QucSDZJQZ
// SIG // vSWA4ejSIqXQugJ6oXeTW2XD7hd0vEGGKtwITIySjJEt
// SIG // nndEH2jWqHR32w5bMotWizO92WPISZ06xcXqMwvS8aMb
// SIG // 9Iu+2bNXizveBKd6IrIkri7HcMW+ToMmCPsLvalPmQjh
// SIG // EChyqs0CAwEAAaOCAVcwggFTMAwGA1UdEwEB/wQCMAAw
// SIG // FgYDVR0lAQH/BAwwCgYIKwYBBQUHAwgwDgYDVR0PAQH/
// SIG // BAQDAgeAMHMGCCsGAQUFBwEBBGcwZTAqBggrBgEFBQcw
// SIG // AYYeaHR0cDovL3RzLW9jc3Aud3Muc3ltYW50ZWMuY29t
// SIG // MDcGCCsGAQUFBzAChitodHRwOi8vdHMtYWlhLndzLnN5
// SIG // bWFudGVjLmNvbS90c3MtY2EtZzIuY2VyMDwGA1UdHwQ1
// SIG // MDMwMaAvoC2GK2h0dHA6Ly90cy1jcmwud3Muc3ltYW50
// SIG // ZWMuY29tL3Rzcy1jYS1nMi5jcmwwKAYDVR0RBCEwH6Qd
// SIG // MBsxGTAXBgNVBAMTEFRpbWVTdGFtcC0yMDQ4LTIwHQYD
// SIG // VR0OBBYEFEbGaaMOShQe1UzaUmMXP142vA3mMB8GA1Ud
// SIG // IwQYMBaAFF+a9W5czMx0mtTdfe8/2+xMgC7dMA0GCSqG
// SIG // SIb3DQEBBQUAA4IBAQB4O7SRKgBM8I9iMDd4o4QnB28Y
// SIG // st4l3KDUlAOqhk4ln5pAAxzdzuN5yyFoBtq2MrRtv/Qs
// SIG // JmMz5ElkbQ3mw2cO9wWkNWx8iRbG6bLfsundIMZxD82V
// SIG // dNy2XN69Nx9DeOZ4tc0oBCCjqvFLxIgpkQ6A0RH83Vx2
// SIG // bk9eDkVGQW4NsOo4mrE62glxEPwcebSAe6xp9P2ctgwW
// SIG // K/F/Wwk9m1viFsoTgW0ALjgNqCmPLOGy9FqpAa8VnCwv
// SIG // SRvbIrvD/niUUcOGsYKIXfA9tFGheTMrLnu53CAJE3Hr
// SIG // ahlbz+ilMFcsiUk/uc9/yb8+ImhjU5q9aXSsxR08f5Lg
// SIG // w7wc2AR1MIIFhTCCBG2gAwIBAgIQKcFbP6rNUmpOZ708
// SIG // Tn4/8jANBgkqhkiG9w0BAQUFADCBtDELMAkGA1UEBhMC
// SIG // VVMxFzAVBgNVBAoTDlZlcmlTaWduLCBJbmMuMR8wHQYD
// SIG // VQQLExZWZXJpU2lnbiBUcnVzdCBOZXR3b3JrMTswOQYD
// SIG // VQQLEzJUZXJtcyBvZiB1c2UgYXQgaHR0cHM6Ly93d3cu
// SIG // dmVyaXNpZ24uY29tL3JwYSAoYykxMDEuMCwGA1UEAxMl
// SIG // VmVyaVNpZ24gQ2xhc3MgMyBDb2RlIFNpZ25pbmcgMjAx
// SIG // MCBDQTAeFw0xMjA3MjUwMDAwMDBaFw0xNTA5MjAyMzU5
// SIG // NTlaMIHIMQswCQYDVQQGEwJVUzETMBEGA1UECBMKQ2Fs
// SIG // aWZvcm5pYTETMBEGA1UEBxMKU2FuIFJhZmFlbDEWMBQG
// SIG // A1UEChQNQXV0b2Rlc2ssIEluYzE+MDwGA1UECxM1RGln
// SIG // aXRhbCBJRCBDbGFzcyAzIC0gTWljcm9zb2Z0IFNvZnR3
// SIG // YXJlIFZhbGlkYXRpb24gdjIxHzAdBgNVBAsUFkRlc2ln
// SIG // biBTb2x1dGlvbnMgR3JvdXAxFjAUBgNVBAMUDUF1dG9k
// SIG // ZXNrLCBJbmMwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAw
// SIG // ggEKAoIBAQCoYmDrmd0Gq8ezSsDlfgaJFEFplNPNhWzM
// SIG // 2uFQaYAB/ggpQ11+N4B6ao+TqrNIWDIqt3JKhaU889nx
// SIG // l/7teWGwuOurstI2Z0bEDhXiXam/bicK2HVLyntliQ+6
// SIG // tT+nlgfN8tgB2NzM0BpE1YCnU2b6DwQw4V7BV+/F//83
// SIG // yGFOpePlumzXxNw9EKWkaq81slmmTxf7UxZgP9PGbLw8
// SIG // gLAPk4PTJI97+5BBqhkLb1YqSfWn3PNMfsNKhw/VwAN0
// SIG // dRKeM6H8SkOdz+osr+NyH86lsKQuics4fwK5uFSHQHsI
// SIG // t6Z0tqWvminRqceUi9ugRlGryh9X1ZqCqfL/ggdzYa3Z
// SIG // AgMBAAGjggF7MIIBdzAJBgNVHRMEAjAAMA4GA1UdDwEB
// SIG // /wQEAwIHgDBABgNVHR8EOTA3MDWgM6Axhi9odHRwOi8v
// SIG // Y3NjMy0yMDEwLWNybC52ZXJpc2lnbi5jb20vQ1NDMy0y
// SIG // MDEwLmNybDBEBgNVHSAEPTA7MDkGC2CGSAGG+EUBBxcD
// SIG // MCowKAYIKwYBBQUHAgEWHGh0dHBzOi8vd3d3LnZlcmlz
// SIG // aWduLmNvbS9ycGEwEwYDVR0lBAwwCgYIKwYBBQUHAwMw
// SIG // cQYIKwYBBQUHAQEEZTBjMCQGCCsGAQUFBzABhhhodHRw
// SIG // Oi8vb2NzcC52ZXJpc2lnbi5jb20wOwYIKwYBBQUHMAKG
// SIG // L2h0dHA6Ly9jc2MzLTIwMTAtYWlhLnZlcmlzaWduLmNv
// SIG // bS9DU0MzLTIwMTAuY2VyMB8GA1UdIwQYMBaAFM+Zqep7
// SIG // JvRLyY6P1/AFJu/j0qedMBEGCWCGSAGG+EIBAQQEAwIE
// SIG // EDAWBgorBgEEAYI3AgEbBAgwBgEBAAEB/zANBgkqhkiG
// SIG // 9w0BAQUFAAOCAQEA2OkGvuiY7TyI6yVTQAYmTO+MpOFG
// SIG // C8MflHSbofJiuLxrS1KXbkzsAPFPPsU1ouftFhsXFtDQ
// SIG // 8rMTq/jwugTpbJUREV0buEkLl8AKRhYQTKBKg1I/puBv
// SIG // bkJocDE0pRwtBz3xSlXXEwyYPcbCOnrM3OZ5bKx1Qiii
// SIG // vixlcGWhO3ws904ssutPFf4mV5PDi3U2Yp1HgbBK/Um/
// SIG // FLr6YAYeZaA8KY1CfQEisF3UKTwm72d7S+fJf++SOGea
// SIG // K0kumehVcbavQJTOVebuZ9V+qU0nk1lMrqve9BnQK69B
// SIG // QqNZu77vCO0wm81cfynAxkOYKZG3idY47qPJOgXKkwmI
// SIG // 2+92ozCCBgowggTyoAMCAQICEFIA5aolVvwahu2WydRL
// SIG // M8cwDQYJKoZIhvcNAQEFBQAwgcoxCzAJBgNVBAYTAlVT
// SIG // MRcwFQYDVQQKEw5WZXJpU2lnbiwgSW5jLjEfMB0GA1UE
// SIG // CxMWVmVyaVNpZ24gVHJ1c3QgTmV0d29yazE6MDgGA1UE
// SIG // CxMxKGMpIDIwMDYgVmVyaVNpZ24sIEluYy4gLSBGb3Ig
// SIG // YXV0aG9yaXplZCB1c2Ugb25seTFFMEMGA1UEAxM8VmVy
// SIG // aVNpZ24gQ2xhc3MgMyBQdWJsaWMgUHJpbWFyeSBDZXJ0
// SIG // aWZpY2F0aW9uIEF1dGhvcml0eSAtIEc1MB4XDTEwMDIw
// SIG // ODAwMDAwMFoXDTIwMDIwNzIzNTk1OVowgbQxCzAJBgNV
// SIG // BAYTAlVTMRcwFQYDVQQKEw5WZXJpU2lnbiwgSW5jLjEf
// SIG // MB0GA1UECxMWVmVyaVNpZ24gVHJ1c3QgTmV0d29yazE7
// SIG // MDkGA1UECxMyVGVybXMgb2YgdXNlIGF0IGh0dHBzOi8v
// SIG // d3d3LnZlcmlzaWduLmNvbS9ycGEgKGMpMTAxLjAsBgNV
// SIG // BAMTJVZlcmlTaWduIENsYXNzIDMgQ29kZSBTaWduaW5n
// SIG // IDIwMTAgQ0EwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAw
// SIG // ggEKAoIBAQD1I0tepdeKuzLp1Ff37+THJn6tGZj+qJ19
// SIG // lPY2axDXdYEwfwRof8srdR7NHQiM32mUpzejnHuA4Jnh
// SIG // 7jdNX847FO6G1ND1JzW8JQs4p4xjnRejCKWrsPvNamKC
// SIG // TNUh2hvZ8eOEO4oqT4VbkAFPyad2EH8nA3y+rn59wd35
// SIG // BbwbSJxp58CkPDxBAD7fluXF5JRx1lUBxwAmSkA8taEm
// SIG // qQynbYCOkCV7z78/HOsvlvrlh3fGtVayejtUMFMb32I0
// SIG // /x7R9FqTKIXlTBdOflv9pJOZf9/N76R17+8V9kfn+Bly
// SIG // 2C40Gqa0p0x+vbtPDD1X8TDWpjaO1oB21xkupc1+NC2J
// SIG // AgMBAAGjggH+MIIB+jASBgNVHRMBAf8ECDAGAQH/AgEA
// SIG // MHAGA1UdIARpMGcwZQYLYIZIAYb4RQEHFwMwVjAoBggr
// SIG // BgEFBQcCARYcaHR0cHM6Ly93d3cudmVyaXNpZ24uY29t
// SIG // L2NwczAqBggrBgEFBQcCAjAeGhxodHRwczovL3d3dy52
// SIG // ZXJpc2lnbi5jb20vcnBhMA4GA1UdDwEB/wQEAwIBBjBt
// SIG // BggrBgEFBQcBDARhMF+hXaBbMFkwVzBVFglpbWFnZS9n
// SIG // aWYwITAfMAcGBSsOAwIaBBSP5dMahqyNjmvDz4Bq1EgY
// SIG // LHsZLjAlFiNodHRwOi8vbG9nby52ZXJpc2lnbi5jb20v
// SIG // dnNsb2dvLmdpZjA0BgNVHR8ELTArMCmgJ6AlhiNodHRw
// SIG // Oi8vY3JsLnZlcmlzaWduLmNvbS9wY2EzLWc1LmNybDA0
// SIG // BggrBgEFBQcBAQQoMCYwJAYIKwYBBQUHMAGGGGh0dHA6
// SIG // Ly9vY3NwLnZlcmlzaWduLmNvbTAdBgNVHSUEFjAUBggr
// SIG // BgEFBQcDAgYIKwYBBQUHAwMwKAYDVR0RBCEwH6QdMBsx
// SIG // GTAXBgNVBAMTEFZlcmlTaWduTVBLSS0yLTgwHQYDVR0O
// SIG // BBYEFM+Zqep7JvRLyY6P1/AFJu/j0qedMB8GA1UdIwQY
// SIG // MBaAFH/TZafC3ey78DAJ80M5+gKvMzEzMA0GCSqGSIb3
// SIG // DQEBBQUAA4IBAQBWIuY0pMRhy0i5Aa1WqGQP2YyRxLvM
// SIG // DOWteqAif99HOEotbNF/cRp87HCpsfBP5A8MU/oVXv50
// SIG // mEkkhYEmHJEUR7BMY4y7oTTUxkXoDYUmcwPQqYxkbdxx
// SIG // kuZFBWAVWVE5/FgUa/7UpO15awgMQXLnNyIGCb4j6T9E
// SIG // mh7pYZ3MsZBc/D3SjaxCPWU21LQ9QCiPmxDPIybMSyDL
// SIG // kB9djEw0yjzY5TfWb6UgvTTrJtmuDefFmvehtCGRM2+G
// SIG // 6Fi7JXx0Dlj+dRtjP84xfJuPG5aexVN2hFucrZH6rO2T
// SIG // ul3IIVPCglNjrxINUIcRGz1UUpaKLJw9khoImgUux5Ol
// SIG // SJHTMYIEcjCCBG4CAQEwgckwgbQxCzAJBgNVBAYTAlVT
// SIG // MRcwFQYDVQQKEw5WZXJpU2lnbiwgSW5jLjEfMB0GA1UE
// SIG // CxMWVmVyaVNpZ24gVHJ1c3QgTmV0d29yazE7MDkGA1UE
// SIG // CxMyVGVybXMgb2YgdXNlIGF0IGh0dHBzOi8vd3d3LnZl
// SIG // cmlzaWduLmNvbS9ycGEgKGMpMTAxLjAsBgNVBAMTJVZl
// SIG // cmlTaWduIENsYXNzIDMgQ29kZSBTaWduaW5nIDIwMTAg
// SIG // Q0ECECnBWz+qzVJqTme9PE5+P/IwCQYFKw4DAhoFAKBw
// SIG // MBAGCisGAQQBgjcCAQwxAjAAMBkGCSqGSIb3DQEJAzEM
// SIG // BgorBgEEAYI3AgEEMBwGCisGAQQBgjcCAQsxDjAMBgor
// SIG // BgEEAYI3AgEVMCMGCSqGSIb3DQEJBDEWBBQsZceVPQso
// SIG // Hp4crnusDqxUAXuKKzANBgkqhkiG9w0BAQEFAASCAQCg
// SIG // S/52pK6vIHFlj0mwMd4Vi7IkOvVZfnjj/ZdwgdFhOG9n
// SIG // xeuNjHG5I0GrVoKdOr7G0R/f0NBGHcewtSsMmyiSAFWp
// SIG // BURhCKafKaoAanQHJHCuBBPAD6FpbCcV5z4pnLWNwkaC
// SIG // WHJaJex7BrxzOY+bA/oP2aj/zRBir8CL5+3uakPOrnqt
// SIG // Fp1+JHzm8wZXhVRmGF7xwESXM/qASdWl7WeMtyiZ5uzh
// SIG // m1+oTOHJSZ0jcwaCz/jetO9Mq7a6oaVINUlW7wKfHq5M
// SIG // 81r0S5H1/nlePIy45FlZHZKQZ+ThqEi86Iz6IjcuD/2W
// SIG // 48nVxSeiT8qAAT42NcMa1aXnTNbn6ITsoYICCzCCAgcG
// SIG // CSqGSIb3DQEJBjGCAfgwggH0AgEBMHIwXjELMAkGA1UE
// SIG // BhMCVVMxHTAbBgNVBAoTFFN5bWFudGVjIENvcnBvcmF0
// SIG // aW9uMTAwLgYDVQQDEydTeW1hbnRlYyBUaW1lIFN0YW1w
// SIG // aW5nIFNlcnZpY2VzIENBIC0gRzICEA7P9DjI/r81bgTY
// SIG // apgbGlAwCQYFKw4DAhoFAKBdMBgGCSqGSIb3DQEJAzEL
// SIG // BgkqhkiG9w0BBwEwHAYJKoZIhvcNAQkFMQ8XDTEzMDQx
// SIG // MTAyMTMwMFowIwYJKoZIhvcNAQkEMRYEFPK+V0bseLnC
// SIG // UdzC4EemJVOwHzdOMA0GCSqGSIb3DQEBAQUABIIBAH1O
// SIG // wTZBEAAy1fiMZmbUX2Q8yHLsdZHci7zt8KneToAa18tl
// SIG // JLmASuPhBubA68/ZnFmjYAECvmA7Lebn1ISCxgLzL0BJ
// SIG // 6LRu+DtssKL0DLaZ9cnTMu38pHGoRi14SmvvsSmUAcm1
// SIG // TO/U34776FZpB7RgblyD02QtGIToS939pVwdHIhLjCtn
// SIG // vOE7G8GWhnl+I6gv+kf922hDHwW8e78Hn15wq56fZb70
// SIG // jy7XT6RGbAJkT6LkD6xaS67XtJb52NroBEcIuPyH3ie2
// SIG // DmTPkFkgFhCTy1pS2pOICJwxWzFVzrO92LyAVnMrDxeD
// SIG // 3BZfVo/TSxhqE6mRhHFu0paXl2QC7fs=
// SIG // End signature block
